==> 0.0.5.tar.gz: lib/widget/vgk-title-widget/vgk-title-widget.dart <==
import 'package:flutter/material.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkTitleWidget extends StatelessWidget {
  final String titleTxt;
  final String subTxt;
  final AnimationController animationController;
  final Animation animation;
  final MaterialColor color;
  final TextStyle titlefontSize;
  final TextStyle subTitlefontSize;
  const VgkTitleWidget({
    this.titleTxt: "",
    this.subTxt: "",
    this.animationController,
    this.animation,
    this.color,
    this.titlefontSize,
    this.subTitlefontSize,
  }) : super();

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Padding(
        padding: const EdgeInsets.only(
          left: VgkprogamingTheme.paddingDoubleExtraLarge,
          right: VgkprogamingTheme.paddingDoubleExtraLarge,
        ),
        child: Row(
          children: <Widget>[
            Expanded(
              child: Text(
                titleTxt,
                textAlign: TextAlign.left,
                style: titlefontSize,
              ),
            ),
            titleViewSubConent(subTxt, subTitlefontSize)
          ],
        ),
      ),
    );
  }

  Widget titleViewSubConent(input, subTitlefontSize) {
    if (input != null && input != '') {
      return InkWell(
        highlightColor: Colors.transparent,
        borderRadius: BorderRadius.all(Radius.circular(4.0)),
        onTap: () {},
        child: Padding(
          padding: const EdgeInsets.only(left: 8),
          child: Row(
            children: <Widget>[
              Text(
                subTxt,
                textAlign: TextAlign.left,
                style: subTitlefontSize,
              ),
              SizedBox(
                height: 38,
                width: 26,
                child: Icon(
                  Icons.arrow_forward,
                  color: VgkprogamingTheme.darkText,
                  size: 18,
                ),
              ),
            ],
          ),
        ),
      );
    } else {
      return Container();
    }
  }
}

==> 0.1.3.tar.gz: lib/widget/vgk-title-widget/vgk-title-widget.dart <==
import 'package:flutter/material.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkTitleWidget extends StatelessWidget {
  final String titleTxt;
  final String subTxt;
  final AnimationController animationController;
  final Animation animation;
  final MaterialColor color;
  final TextStyle titlefontSize;
  final TextStyle subTitlefontSize;
  const VgkTitleWidget({
    this.titleTxt: "",
    this.subTxt: "",
    this.animationController,
    this.animation,
    this.color,
    this.titlefontSize,
    this.subTitlefontSize,
  }) : super();

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Padding(
        padding: const EdgeInsets.only(
          left: VgkprogamingTheme.paddingDoubleExtraLarge,
          right: VgkprogamingTheme.paddingDoubleExtraLarge,
        ),
        child: Row(
          children: <Widget>[
            Expanded(
              child: Text(
                titleTxt,
                textAlign: TextAlign.left,
                style: titlefontSize != null
                    ? titlefontSize
                    : VgkprogamingTheme.h1,
              ),
            ),
            titleViewSubConent(subTxt, subTitlefontSize)
          ],
        ),
      ),
    );
  }

  Widget titleViewSubConent(input, subTitlefontSize) {
    if (input != null && input != '') {
      return InkWell(
        highlightColor: Colors.transparent,
        borderRadius: BorderRadius.all(Radius.circular(4.0)),
        onTap: () {},
        child: Padding(
          padding: const EdgeInsets.only(left: 8),
          child: Row(
            children: <Widget>[
              Text(
                subTxt,
                textAlign: TextAlign.left,
                style: subTitlefontSize != null
                    ? subTitlefontSize
                    : VgkprogamingTheme.h3,
              ),
              SizedBox(
                height: 38,
                width: 26,
                child: Icon(
                  Icons.arrow_forward,
                  color: VgkprogamingTheme.darkText,
                  size: 18,
                ),
              ),
            ],
          ),
        ),
      );
    } else {
      return Container();
    }
  }
}
